@@ -21,7 +21,7 @@
 #ifndef _NAUTILUS_BURN_H
 #define _NAUTILUS_BURN_H
 
-#include <glib/gtypes.h>
+#include <glib.h>
 
 G_BEGIN_DECLS
 
